@@ -2,6 +2,7 @@
 
 use 5.014;
 use warnings;
+
 use FindBin;
 use lib ("$FindBin::Bin/../lib");
 
@@ -25,7 +26,7 @@ push @commands, Term::CLI::Command->new(
     callback => sub {
         my ($cmd, %args) = @_;
         return %args if $args{status} < 0;
-        execute_exit($cmd->name, @{$args{arguments}});
+        execute_exit($cmd, @{$args{arguments}});
         return %args;
     },
     arguments => [
@@ -42,7 +43,7 @@ push @commands, Term::CLI::Command->new(
 sub execute_exit {
     my ($cmd, $excode) = @_;
     $excode //= 0;
-    say "-- $cmd: $excode";
+    say "-- exit: $excode";
     exit $excode;
 }
 
@@ -55,4 +56,4 @@ while ( defined(my $line = $term->readline) ) {
     $term->execute($line);
 }
 print "\n";
-execute_exit('exit', 0);
+execute_exit($term, 0);
